// LM45.h

// Header file for the CLM45 class.
//
// Pat Summers
// American LaserWare, Inc.

#ifndef	LM45
#define LM45

// Include all revision notes
#include "LM45_Ver.h"
// Include the definition of constants used by this class
// (excluding hardware IO)
#include "LM45_Constants.h"
// Include the definitions for the LM45 PC Control board
#include "LM45_Board.h"
// Include the header for members
#include "LM45Share.h"

// Define the class

class CLM45	: public CObject
{
public:
	// Version number for class
	UINT
		m_nVersion;
	// Constructor
	CLM45(void);
	// Destructor
	~CLM45(void);

	// Initalization for class
	void Init(BOOL bManager = FALSE);
	// Initalization of the hardware
	void InitBoard(void);

	// Determines if the address space is
	// used for input of output
	BOOL IsInputPort(WORD);
	// Custom Input / Output functions that
	// maintains the output port states in
	// m_wPort0xXXXX member variables
	// Using these i/o functions allows us
	// treat all ports as both read and write
	WORD Input(WORD);
	void Output(WORD, WORD);
	
	// Used for implementing I/O
	void SelectValue(int);
	void LatchValue(int);
	// Board status during ADC
	BOOL IsBusy(void);

	// Sharing
	CLM45Share
		m_LM45Share;
	BOOL CanModifySettings(void);

	// Cooling water
	BOOL IsWaterFlowOk(void);
	BOOL IsWaterLevelOk(void);
	BOOL IsWaterOverTemp(void);
	BOOL IsPumpOn(void);
	BOOL SetPumpPower(BOOL);
	BOOL GetPumpPower(void);
	float GetWaterTemp(void);
	float GetWaterCond(void);
	BOOL IsSolValveOpen(void);

	// Oscillator
	BOOL IsShutterOpen(void);
	BOOL IsShutterClosed(void);
	BOOL SetShutter(BOOL);
	BOOL GetShutter(void);
	BOOL IsOscCoverOpen(void);
	BOOL IsQSOverTemp(void);
	BOOL IsGuideBeamOn(void);
	BOOL SetGuideBeam(BOOL);
	BOOL GetGuideBeam(void);
	WORD GetXGalvo(void);
	WORD GetYGalvo(void);
	WORD SetXGalvo(WORD);
	WORD SetYGalvo(WORD);
	BOOL SetPosition(WORD, WORD);

	// QSwitch Driver
	BOOL IsQsdOn(void);
	BOOL SetQSDPower(BOOL);
	BOOL GetQSDPower(void);
	BOOL IsQsdVSWROK(void);
	BOOL IsQsdOverTemp(void);
	BOOL IsQsdHFOutOK(void);
	BOOL IsCWModeOn(void);
	BOOL SetCWMode(BOOL);
	BOOL GetCWMode(void);
	float GetQSFreq(void);
	BOOL SetQSFreq(float, float *pActual = NULL);
	float GetQSModFactor(void);
	BOOL SetQSModFactor(float, float *pActual = NULL);
	BOOL IsGateOpen(void);
	BOOL SetQSDGate(BOOL);
	BOOL GetQSDGate(void);

	// Power Supply
	BOOL IsLampOn(void);
	BOOL SetLampPower(BOOL);
	BOOL GetLampPower(void);
	BOOL IsPSOverTemp(void);
	BOOL IsPSOverCurrent(void);
	float GetLampCurrent(void);
	float GetLampSetting(void);
	BOOL SetLampCurrent(float, float *pActual = NULL);
	BOOL GetPSTroubleReset(void);
	BOOL SetPSTroubleReset(BOOL);

	// Panel
	BOOL IsKeyOn(void);
	BOOL IsEMStopOn(void);
	BOOL IsRemoteInterlockOn(void);
	BOOL IsMainCoverOpen(void);
	BOOL IsPanelResetPressed(void);
	BOOL IsPanelStartPressed(void);
	BOOL IsPanelStopPressed(void);

	// LEDs
	BOOL IsPanelReadyLEDOn(void);
//	BOOL SetPanelReadyLED(void);
	BOOL SetPanelReadyLED(BOOL);
	BOOL IsPanelTroubleLEDOn(void);
	BOOL SetPanelTroubleLED(BOOL);
	BOOL IsPanelLaserLEDOn(void);
//	BOOL SetPanelLaserLED(void);
	BOOL SetPanelLaserLED(BOOL);

	// External
	BOOL IsExtControlOn(void);
	BOOL IsExtResetPressed(void);
	BOOL IsExtStartPressed(void);
	BOOL IsExtStopPressed(void);
	unsigned char GetExtScheduleNumber(void);
	BOOL IsExtScheduleParityOdd(void);
	BOOL IsExtShutterOpenPressed(void);
	BOOL IsExtLampOnPressed(void);
	BOOL IsExtCounterResetPressed(void);
	BOOL IsExtCounterStopPressed(void);
	BOOL GetExtMarkingReady(void);
	BOOL SetExtMarkingReady(BOOL);
	BOOL GetExtMarkingNow(void);
	BOOL SetExtMarkingNow(BOOL);
	BOOL GetExtMarkingDone(void);
	BOOL SetExtMarkingDone(BOOL);
	BOOL GetExtTrouble(void);
	BOOL SetExtTrouble(BOOL);
	BOOL GetExtCounterUp(void);
	BOOL SetExtCounterUp(BOOL);

	// Board
	BOOL EnableDAC(BOOL);

	void GetAllADCValues(float *, float *, float *);
	
	// Initialization of the LM45 board
	BOOL SetInitialState(void);
	
	// Unit/type conversion
	float WordToDegrees(WORD);
	WORD DegreesToWord(float);
	float WordToOhms(WORD);
	WORD OhmsToWord(float);
	float WordToAmps(WORD);
	float WordToAmpsADC(WORD);
	WORD AmpsToWord(float);
	float WordToHertz(WORD);
	WORD HertzToWord(float);
	float WordToModFactor(WORD);
	WORD ModFactorToWord(float);

	int
		m_iADCState;
	BOOL GetWaterTempX(BOOL *, float *);
	BOOL GetWaterCondX(BOOL *, float *);
	BOOL GetLampCurrentX(BOOL *, float *);
	BOOL GetAllADCValuesX(float *, float *, float *);

	/*** REV L002 - 19990606 - GPOUTPUTVALUE FUNCTION ***/
	BYTE GetGPOutputValue(void);
	BYTE GetGPInputValue(void);
	/*** REV L002 ***************************************/

	/*** REV L007 - 19990715 - HENE/LAMP CURRENT LIMIT ***/
	BOOL WaitForMinLampCurrent(int iTimeout = 10);
	/*** REV L007 ****************************************/

};

#endif	// LM45


